@@ -227,6 +227,12 @@ class OutputFiles(object):
         elif format_as == 'CSV':
             from galaxygetopt.writer.csv_w import CSV_W
             return CSV_W()
+        elif format_as == 'Fasta':
+            from galaxygetopt.writer.fasta import Fasta
+            return Fasta()
+        elif format_as == 'Genbank':
+            from galaxygetopt.writer.genbank import Genbank
+            return Genbank()
         else:
             raise NoAvailableOutputHandlerError("Could not find an appropriate output handler")
 
